# sqlite-database-library by SiiHino
library for work with sqlite3

view template.py for to get acquainted with the contents of the library

PyPl - https://pypi.org/project/sqlitedl/1.2/
setup command - pip install sqlitedl==1.2
